# mautrix-facebook
![Languages](https://img.shields.io/github/languages/top/tulir/mautrix-facebook.svg)
[![License](https://img.shields.io/github/license/tulir/mautrix-facebook.svg)](LICENSE)
[![Release](https://img.shields.io/github/release/tulir/mautrix-facebook/all.svg)](https://github.com/tulir/mautrix-facebook/releases)
[![GitLab CI](https://mau.dev/tulir/mautrix-facebook/badges/master/pipeline.svg)](https://mau.dev/tulir/mautrix-facebook/container_registry)

A Matrix-Facebook Messenger puppeting bridge.

## Documentation
All setup and usage instructions are located on
[docs.mau.fi](https://docs.mau.fi/bridges/python/facebook/index.html).
Some quick links:

* [Bridge setup](https://docs.mau.fi/bridges/python/setup/index.html?bridge=facebook)
  (or [with Docker](https://docs.mau.fi/bridges/python/setup/docker.html?bridge=facebook))
* Basic usage: [Authentication](https://docs.mau.fi/bridges/python/facebook/authentication.html)

### Features & Roadmap
[ROADMAP.md](https://github.com/tulir/mautrix-facebook/blob/master/ROADMAP.md)
contains a general overview of what is supported by the bridge.

## Discussion
Matrix room: [`#facebook:maunium.net`](https://matrix.to/#/#facebook:maunium.net)
